==> zio-aws-directconnect_2.12-5.17.155.2-sources.jar: zio/aws/directconnect/model/DeleteDirectConnectGatewayAssociationResponse.scala <==
package zio.aws.directconnect.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DeleteDirectConnectGatewayAssociationResponse(
    directConnectGatewayAssociation: Option[
      zio.aws.directconnect.model.DirectConnectGatewayAssociation
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.directconnect.model.DeleteDirectConnectGatewayAssociationResponse = {
    import DeleteDirectConnectGatewayAssociationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.directconnect.model.DeleteDirectConnectGatewayAssociationResponse
      .builder()
      .optionallyWith(
        directConnectGatewayAssociation.map(value => value.buildAwsValue())
      )(_.directConnectGatewayAssociation)
      .build()
  }
  def asReadOnly
      : zio.aws.directconnect.model.DeleteDirectConnectGatewayAssociationResponse.ReadOnly =
    zio.aws.directconnect.model.DeleteDirectConnectGatewayAssociationResponse
      .wrap(buildAwsValue())
}
object DeleteDirectConnectGatewayAssociationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.directconnect.model.DeleteDirectConnectGatewayAssociationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.directconnect.model.DeleteDirectConnectGatewayAssociationResponse =
      zio.aws.directconnect.model.DeleteDirectConnectGatewayAssociationResponse(
        directConnectGatewayAssociation.map(value => value.asEditable)
      )
    def directConnectGatewayAssociation: Option[
      zio.aws.directconnect.model.DirectConnectGatewayAssociation.ReadOnly
    ]
    def getDirectConnectGatewayAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.directconnect.model.DirectConnectGatewayAssociation.ReadOnly
    ] = AwsError.unwrapOptionField(
      "directConnectGatewayAssociation",
      directConnectGatewayAssociation
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.directconnect.model.DeleteDirectConnectGatewayAssociationResponse
  ) extends zio.aws.directconnect.model.DeleteDirectConnectGatewayAssociationResponse.ReadOnly {
    override val directConnectGatewayAssociation: Option[
      zio.aws.directconnect.model.DirectConnectGatewayAssociation.ReadOnly
    ] = scala
      .Option(impl.directConnectGatewayAssociation())
      .map(value =>
        zio.aws.directconnect.model.DirectConnectGatewayAssociation.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.directconnect.model.DeleteDirectConnectGatewayAssociationResponse
  ): zio.aws.directconnect.model.DeleteDirectConnectGatewayAssociationResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-directconnect_2.12-5.17.267.6-sources.jar: zio/aws/directconnect/model/DeleteDirectConnectGatewayAssociationResponse.scala <==
package zio.aws.directconnect.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DeleteDirectConnectGatewayAssociationResponse(
    directConnectGatewayAssociation: Optional[
      zio.aws.directconnect.model.DirectConnectGatewayAssociation
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.directconnect.model.DeleteDirectConnectGatewayAssociationResponse = {
    import DeleteDirectConnectGatewayAssociationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.directconnect.model.DeleteDirectConnectGatewayAssociationResponse
      .builder()
      .optionallyWith(
        directConnectGatewayAssociation.map(value => value.buildAwsValue())
      )(_.directConnectGatewayAssociation)
      .build()
  }
  def asReadOnly
      : zio.aws.directconnect.model.DeleteDirectConnectGatewayAssociationResponse.ReadOnly =
    zio.aws.directconnect.model.DeleteDirectConnectGatewayAssociationResponse
      .wrap(buildAwsValue())
}
object DeleteDirectConnectGatewayAssociationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.directconnect.model.DeleteDirectConnectGatewayAssociationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.directconnect.model.DeleteDirectConnectGatewayAssociationResponse =
      zio.aws.directconnect.model.DeleteDirectConnectGatewayAssociationResponse(
        directConnectGatewayAssociation.map(value => value.asEditable)
      )
    def directConnectGatewayAssociation: Optional[
      zio.aws.directconnect.model.DirectConnectGatewayAssociation.ReadOnly
    ]
    def getDirectConnectGatewayAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.directconnect.model.DirectConnectGatewayAssociation.ReadOnly
    ] = AwsError.unwrapOptionField(
      "directConnectGatewayAssociation",
      directConnectGatewayAssociation
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.directconnect.model.DeleteDirectConnectGatewayAssociationResponse
  ) extends zio.aws.directconnect.model.DeleteDirectConnectGatewayAssociationResponse.ReadOnly {
    override val directConnectGatewayAssociation: Optional[
      zio.aws.directconnect.model.DirectConnectGatewayAssociation.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.directConnectGatewayAssociation())
      .map(value =>
        zio.aws.directconnect.model.DirectConnectGatewayAssociation.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.directconnect.model.DeleteDirectConnectGatewayAssociationResponse
  ): zio.aws.directconnect.model.DeleteDirectConnectGatewayAssociationResponse.ReadOnly =
    new Wrapper(impl)
}
